@@ -5,7 +5,6 @@ import shutil
 import sys
 import json
 import tempfile
-import subprocess
 from os.path import basename, join
 from typing import Sequence
 import jmespath
@@ -28,6 +27,9 @@ __all__ = [
 ]
 
 
+Image.MAX_IMAGE_PIXELS = idk.sdk_opts.image_max_pixels
+
+
 def image_normalize(img):
     # type: (Image.Image) -> Sequence[int]
     """
@@ -54,7 +56,7 @@ def image_normalize(img):
     img = img.convert("L")
 
     # Resize to 32x32
-    im = img.resize((32, 32), Image.Resampling.BICUBIC)
+    im = img.resize((32, 32), idk.BICUBIC)
 
     # A flattened sequence of grayscale pixel values (1024 pixels)
     pixels = im.getdata()
@@ -167,8 +169,9 @@ def image_meta_embed(fp, meta):
     cmdf = "reg iscc http://purl.org/iscc/schema\n"
     cmdf += "reg dc http://purl.org/dc/elements/1.1/\n"
 
-    cmdf += f"set Xmp.iscc.name {meta.name}\n"
-    cmdf += f"set Xmp.dc.title {meta.name}\n"
+    if meta.name:
+        cmdf += f"set Xmp.iscc.name {meta.name}\n"
+        cmdf += f"set Xmp.dc.title {meta.name}\n"
     if meta.description:
         cmdf += f"set Xmp.iscc.description {meta.description}\n"
         cmdf += f"set Xmp.dc.description {meta.description}\n"
@@ -223,7 +226,7 @@ def image_thumbnail(fp):
     """
     size = idk.sdk_opts.image_thumbnail_size
     img = Image.open(fp)
-    img.thumbnail((size, size), resample=Image.Resampling.LANCZOS)
+    img.thumbnail((size, size), resample=idk.LANCZOS)
     return ImageEnhance.Sharpness(img.convert("RGB")).enhance(1.4)
 
 
