@@ -1,9 +1,7 @@
 """IPFS wrapper"""
 import sys
 from os.path import basename
-
 import iscc_sdk as idk
-import subprocess
 
 
 __all__ = [
@@ -24,11 +22,11 @@ def ipfs_cidv1(fp, wrap=False):
     :return: IPFS CIDv1 of the file
     :rtype: str
     """
-    cmd = [idk.ipfs_bin(), "add", "--only-hash", "--cid-version=1", "--offline", "--quieter"]
+    args = ["add", "--only-hash", "--cid-version=1", "--offline", "--quieter"]
     if wrap:
-        cmd.append("--wrap-with-directory")
-    cmd.append(fp)
-    result = subprocess.run(cmd, capture_output=True, check=True)
+        args.append("--wrap-with-directory")
+    args.append(fp)
+    result = idk.run_ipfs(args)
     cid = result.stdout.decode(sys.stdout.encoding).strip()
     if wrap:
         cid += f"/{basename(fp)}"
@@ -44,8 +42,7 @@ def ipfs_cidv1_base16(fp):
     :return: IPFS CIDv1 of the file in base16 (hex)
     :rtype: str
     """
-    cmd = [
-        idk.ipfs_bin(),
+    args = [
         "add",
         "--only-hash",
         "--cid-version=1",
@@ -54,6 +51,5 @@ def ipfs_cidv1_base16(fp):
         "--cid-base=base16",
         fp,
     ]
-
-    result = subprocess.run(cmd, capture_output=True, check=True)
+    result = idk.run_ipfs(args)
     return result.stdout.decode(sys.stdout.encoding).strip()
