@@ -67,9 +67,9 @@ FPCALC_CHECKSUMS = {
     "darwin-64": "afea164b0bc9b91e5205d126f96a21836a91ea2d24200e1b7612a7304ea3b4f1",
 }
 
-TIKA_VERSION = "2.3.0"
+TIKA_VERSION = "2.6.0"
 TIKA_URL = f"{BASE_URL}/tika-app-{TIKA_VERSION}.jar"
-TIKA_CHECKSUM = "e3f6ff0841b9014333fc6de4b849704384abf362100edfa573a6e4104b654491"
+TIKA_CHECKSUM = "4e91e89461a67c6a28c401ab131288979e76d3edca7bbb0b2f4844dd3539358e"
 
 EXIV2_VERSION = "0.27.2"
 EXIV2_URLS = {
@@ -128,7 +128,26 @@ def extract(archive):  # pragma: no cover
 
     elif archive.endswith("tar.gz"):
         with tarfile.open(archive, "r:gz") as tar_file:
-            tar_file.extractall(Path(archive).parent.absolute())
+
+            def is_within_directory(directory, target):
+
+                abs_directory = os.path.abspath(directory)
+                abs_target = os.path.abspath(target)
+
+                prefix = os.path.commonprefix([abs_directory, abs_target])
+
+                return prefix == abs_directory
+
+            def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
+
+                for member in tar.getmembers():
+                    member_path = os.path.join(path, member.name)
+                    if not is_within_directory(path, member_path):
+                        raise Exception("Attempted Path Traversal in Tar File")
+
+                tar.extractall(path, members, numeric_owner=numeric_owner)
+
+            safe_extract(tar_file, Path(archive).parent.absolute())
     os.unlink(archive)
 
 
